package duppy

  1. Overview
  2. Docs

Module type Mutex.Mutex_controlSource

Information used to initialize a Mutex module. * priority and scheduler are used to initialize a task * which treat mutexes as well as conditions from the below * Condition module.

Sourcetype priority
Sourceval scheduler : priority scheduler
Sourceval priority : priority